#
# spec file for package perl-Config-Any
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Config-Any
Name:           perl-Config-Any
Version:        0.33
Release:        1.3
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Load configuration from different file formats, transparently
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/H/HA/HAARG/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Pluggable::Object) >= 3.6
Requires:       perl(Module::Pluggable::Object) >= 3.6
%{perl_requires}

%description
Config::Any provides a facility for Perl applications and libraries to load
configuration data from multiple different file formats. It supports XML,
YAML, JSON, Apache-style configuration, Windows INI files, and even Perl
code.

The rationale for this module is as follows: Perl programs are deployed on
many different platforms and integrated with many different systems.
Systems administrators and end users may prefer different configuration
formats than the developers. The flexibility inherent in a multiple format
configuration loader allows different users to make different choices,
without generating extra work for the developers. As a developer you only
need to learn a single interface to be able to use the power of different
configuration formats.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Thu May  4 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.33
  see /usr/share/doc/packages/perl-Config-Any/Changes
  0.33 - 2023-05-03
  - update docs describe which modules are needed for which formats
  - update Config::General requirement for conf files to a non-broken
    version (2.48)
  - don't try to upgrade old Config::General versions
  - fix is_supported method verifying the version of required modules
  - documentation cleanups
* Tue Apr 25 2017 coolo@suse.com
- updated to 0.32
  see /usr/share/doc/packages/perl-Config-Any/Changes
  0.32 - 2017-04-23
  - allow YAML::Syck to fail its error tests
  - improved diagnostics in YAML test
  - include a full list of modules used in JSON documentation
  - be less strict checking error messages in tests
  - add test to report optional prereq versions
  0.31 - 2017-04-23
  - test cleanups
  - better diagnostics for test failures
  - don't run pod tests on user machines
  - handle unsupported Config::General versions better
  - refactored module loading
  - include optional prereqs in suggests
  - pod cleanups
* Thu Mar 30 2017 coolo@suse.com
- updated to 0.30
  see /usr/share/doc/packages/perl-Config-Any/Changes
  0.30 - 2017-03-28
  - don't use YAML::Syck on perl 5.8.8 or below, where it is broken
  - ensure tarball does not contain SCHILY headers
* Wed Mar  1 2017 coolo@suse.com
- updated to 0.29
  see /usr/share/doc/packages/perl-Config-Any/Changes
  0.29 - 2017-02-27
  - allow loading relative perl files even under taint mode (RT#120371)
  - throw errors when attempting to load perl files that do not exist
* Wed Feb 22 2017 coolo@suse.com
- updated to 0.28
  see /usr/share/doc/packages/perl-Config-Any/Changes
  0.28 - 2017-02-21
  - support Cpanel::JSON::XS and JSON::MaybeXS for loading JSON
  - decode UTF-8 config files properly
  - load perl files directly, never possibly searching @INC
* Mon Apr  4 2016 coolo@suse.com
- updated to 0.27
  see /usr/share/doc/packages/perl-Config-Any/Changes
  0.27 2016-03-31
  - depend on Module::Pluggable::Object directly instead of assuming it is
    bundled with Module::Pluggable (RT #113148)
* Thu Apr 30 2015 coolo@suse.com
- updated to 0.26
  see /usr/share/doc/packages/perl-Config-Any/Changes
  0.26 2015-04-29
  - fix error reporting from code applied in 0.25 (RT #104079)
* Fri Apr 24 2015 coolo@suse.com
- updated to 0.25
  see /usr/share/doc/packages/perl-Config-Any/Changes
  0.25 2015-04-23
  - do not clobber $@ (RT #103061)
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.24
  - remove 4-year-old warning about YAML::XS not being installed
  - add JSON::PP to list of available JSON parsers (RT #86959)
* Fri Dec 23 2011 coolo@suse.com
- update to 0.23
  - fix test suite's method of checking availability of plugins
  - add XML::NamespaceSupport to XML format deps, silence YAML warnings in
    tests (caelum)
* Wed Jun  8 2011 coolo@novell.com
- updated to 0.21
  - fix t/64-extfail.t to pass when t/lib is in @INC
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Mon Jun 14 2010 pascal.bleser@opensuse.org
- initial version (0.19)
